Kandula
#######

Kandula is a Python package for general Reinforcement Learning (RL). You can use Kandula to apply RL to your owns problem. You can see the documentations
`here <https://>`__.

Usage
#####

.. code:: bash

    pip install kandula
    
You can see two worked examples of training an RL agent to learn to multiply and to learn to predict country capitals in `these notebooks <./notebooks>`.